@@ -12,18 +12,22 @@ from flask_sketch.questions import get_questions
 
 parser = argparse.ArgumentParser(description="Flask Sketch CLI")
 parser.add_argument("project_name", type=str)
-parser.add_argument("-e", action="store_true", help="Create examples endpoints")
-parser.add_argument(
-    "-p", action="store_true", help="Create a pyproject.toml to work with poetry",
-)
 parser.add_argument(
     "-v", action="store_true", help="Create a virtualenv.",
 )
+# parser.add_argument(
+#     "-e", action="store_true", help="Create examples endpoints"
+# )
+# parser.add_argument(
+#     "-p",
+#     action="store_true",
+#     help="Create a pyproject.toml to work with poetry",
+# )
 
 f = Figlet(font="slant")
 
 
-def main(args):
+def flask_sketch(args):
     print(f.renderText("Flask Sketch"))
 
     answers = prompt(get_questions(), style=cli_style_2)
@@ -31,11 +35,12 @@ def main(args):
         create_project(args, answers)
 
 
-def flask_sketch():
+def main():
     args = parser.parse_args()
     args.project_name = args.project_name.lower()
+    tb = None
     try:
-        main(args)
+        flask_sketch(args)
     except FileExistsError as e:
         print("\n\nAn error occurred during generating files:")
         print(e)
@@ -45,12 +50,10 @@ def flask_sketch():
         print(e)
         shutil.rmtree(args.project_name)
         tb = traceback.format_exc()
-    else:
-        tb = None
     finally:
         if tb:
             print("\n\n", tb)
 
 
 if __name__ == "__main__":
-    flask_sketch()
+    main()
